% Makes I2C/BL233 command files to read I2C EEProms from 24C00 - 24M04
NumRd=64; %read N bytes per line
BlockSize=64; %base size of a 24C00, and
I2CBase=hex2dec('A0');
fdir='';
fbase='ReadIMem_';
PasFName='I2CEEProm_Definitions.pas'; %automatically make a file of strings
BiggestMem=14; %4Mbit (2Mbit * 2)
SizeOfBiggestMem=2^(BiggestMem+7);
fpas=fopen(PasFName,'wt');
fprintf(fpas,'{autogenerated definitions file by MakeReadFiles.m}\nconst I2CEEPromDefinitionsStr:string =\n');

for NE=1:BiggestMem %for each memory size, make a new file. NE=exponent of number of 128 byte blocks 
    NumBlocks=2^(NE-1)
    if NumBlocks<64
        PointerBytes=1;
        PointerFmt='%02X';
        PointerMod=256;
        PointerEOL=' ';
    else
        PointerBytes=2;
        PointerFmt='%04X';
        PointerMod=2^16;
        PointerEOL=' ';
    end
    MemSize=BlockSize*NumBlocks;
    if NE==1
        K=0;
    else
      K=2^(NE-2);  
    end
    ChipStr=sprintf('24xx%02d',K);
    WriteTime=5; 
    switch NE
        case 1 , PageSize=1;        %write page size
        case {2,3} , PageSize=8;
        case 4 , PageSize=16;
        otherwise PageSize= min(2^floor((NE+3)/2),256) %actual page size of chip
    end; %switch
    MemSize=BlockSize*NumBlocks;
    
    %---- Emit FPAS part ----
    fprintf(fpas,'  ''%s,%i,%i,%i,%i''+CRLF+\n',ChipStr,PointerBytes,PageSize,WriteTime,MemSize);
    Add=0;
    I2CAdd=I2CBase-2; % the write address    
    %---- S19 part -------
    fname=fullfile(fdir,[fbase,'S19_',ChipStr,'.i2c']) %make the file name for each chip size
    fid=fopen(fname,'w+t');
    fprintf(fid,'J88'); %disable auto linefeeds
    
    NN=0;  
    for Block=1:NumBlocks
        Pointer=mod(Add,PointerMod);
        if Pointer==0  %reset the pointer and bump I2C Address
            I2CAdd=I2CAdd+2; %move I2C Address       
            NN=0;
        end
        if mod(NN,4)==0      % i.e. every 256bytes have a new line 
               fprintf(fid, ['\nS%02X',PointerFmt,PointerEOL],I2CAdd,Pointer); %send addr and pointer
        end
        for ReadLine=[1:BlockSize/NumRd] %
            %S32<Length><add><data><check>
            RecordLengthHex=dec2hex(dec2hex(3 + NumRd + 1,2))'; %hex of hex for T command
            AddHex=dec2Hex(dec2hex(Add,6))'; %hex of hex for T command
            fprintf(fid,['T5332%s%sR%02XT3737. '],RecordLengthHex,AddHex,NumRd);
            Add=Add+NumRd; %move address  
            NN=NN+1;
        end %for line
        
    end %for block
    fclose(fid);
    
        %---- Plain HEX part -------
    fname=fullfile(fdir,[fbase,'Hex_',ChipStr,'.i2c']) %make the file name for each chip size
    fid=fopen(fname,'w+t');
    fprintf(fid,'J88'); %disable auto linefeeds
    NumAddBlocks=ceil(MemSize/PointerMod);
    AddBlockSize=min(MemSize,PointerMod);
    Pointer=0;
    for AddBlock=1:NumAddBlocks
       I2CAdd=I2CBase + (AddBlock-1)*2; %
       fprintf(fid, ['\nS%02X',PointerFmt,'R'],I2CAdd,Pointer); %reset the pointer and bump I2C Address
       NumFFs=floor(AddBlockSize/255);  
       BlockRemainder=AddBlockSize - (NumFFs*255);
       for i=1:NumFFs %
            fprintf(fid,'FF');
            if 0==mod(i,50)
                fprintf(fid,'\n');
            end    
        end %for line 
        fprintf(fid,'%02XP',BlockRemainder);
    end %for block
    fprintf(fid,'.'); %eol only at end of data file  
    fclose(fid);

end %for each memory
fprintf(fpas,'  s'''';');
fclose(fpas);