rem Routine to convert an eeprom data file  and program an I2C EEProm
rem Usage see end of this file
echo off


rem --------- ----------------------------Setup Block ----------------------------
setlocal

rem ------- Set location of tools, ports etc ------------
rem define the locations of the utilities and file names etc.
set RTDir=%ProgramFiles%\BEL\Realterm\
rem if you don't have SRECORD, there is a link in the realterm/utils dir to download it
set srecord="%RTDIR%utils\srec_cat.exe"
set sed="%RTDir%utils\sed.exe"
set RT= "%RTDir%realterm.exe"
set ComPort=\VCP0
set TempFileName=EEPromTmp

rem ---------- Process command line params, and set default values etc -------------

rem allow suppression of programming call to realterm at end.
set NOPROGRAM=0 
if not [%1]==[NOPROGRAM] goto DoProgram
  SHIFT
  set NOPROGRAM=1
:DoProgram

rem %1 will be hex file at this point....

rem Check %2 to see if it can be an eeprom type eg "24xx01" , and call batch file to parse it if it is
if [%2] == [] goto SetDefaults
if [%2] ==1 goto SetDefaults
if [%2] ==2 goto SetDefaults
rem if we get here, %2 (pointerbytes) is not 1 or 2 ie might be an eeprom type so parse types and overwrite all the options from that file
call I2CEEPromTypes.bat %2
if Errorlevel 1 goto SetDefaults
rem else we did find matching eeprom name at set values
goto pagesizedone

:SetDefaults

rem set the default number of pointer bytes 1 for <=24Xxx6, 2 for >=24xx32 
if not [%2] == [] set pointerbytes=%2
if not defined pointerbytes set pointerbytes=1

rem The write time must be a single uppercase hex character. most eeproms have 5ms max write time. ST 24M02 is 10ms ie use"A"
if not [%3] == [] set WriteTimeHex=%3
if not defined WriteTimeHex set WriteTimeHex=5

rem set PageSize. automatically default pagesize to suit most eeproms 24C01 up 

if not [%4] == [] set pagesize=%4
if defined pagesize goto pagesizedone

echo %1, %pointerbytes% %pagesize%, %writetimehex%, %rd128%

if %pointerbytes% == 1 set pagesize=8 & goto pagesizedone
if %pointerbytes% == 2 set pagesize=32 & goto pagesizedone

rem Overwrite pagesize with the perfect value if you want here. 128 is the max value 
:pagesizedone

rem SRecord files can only have max 128 bytes
if %pagesize% GEQ 128 set pagesize=128

rem ------------ Make some checks for missing things --------
if not exist %srecord% goto MissingSREC
if [%1] == [] goto Usage
if not exist %1 goto MissingHex


rem ----------- Now begin doing stuff ---------------------

rem Delete any existing intermediate files to avoid cockups
erase %TempFileName%.srec  %TempFileName%.i2c

rem convert hex file format to S2, and resize into correct pagesize
%srecord% %1 -Output_Block_Size %pagesize% -Output_Block_Alignment -o %TempFileName%.srec -address-length=3

rem convert to BL233B command file
sed  -n -f s2hex.sed -f TrimChars%pointerbytes%.sed -f mapadd.sed -e "s/^SA.*$/& P L000%WriteTimeHex%/p" %TempFileName%.srec >  %TempFileName%.i2c

if %NOPROGRAM%==1 exit /B
rem send to I2C2PC adaptor
start "Programming I2C EEProm" /wait %RT% port=%ComPort% flow=2 sendquit=%TempFileName%.i2c

exit /B
rem ---------------  errors -----------------
:MissingSREC
echo ******** ERROR *************
echo You need to install SRECORD or change this batch file to point at it. %srecord%
pause 
exit /B 2

:Usage
echo ******** ERROR *************
echo Usage: ProgramI2CEEProm YourDataFile
echo Usage: ProgramI2CEEProm YourDataFile <EEProm Type>
echo Usage: ProgramI2CEEProm YourDataFile [Number of Pointer Bytes 1 or 2] [hex delay in ms eg 5 or A] [pagesize]
echo Usage: ProgramI2CEEProm NOPROGRAM YourDataFile   //only do file convert to %TempFileName%.i2c 
echo .
type I2CEEPromTypes.bat 
:MissingHex
echo ******** ERROR *************
echo Missing input hex file: %1
pause 
exit /B 1
endlocal
